<?php
/**
 * datum setup
 *
 * @package datuuserince   3.2.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Main datum Class.
 *
 * @class datum
 */
if(!class_exists('WP_List_Table')){
   require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}
if (!class_exists('datum')) {
		
	final class datum {
		
		private static $instance;
		public $version = "1.0.0";
		
		public $wp_version = "3.5";
		
		public static function instance() {
			if (!isset(self::$instance) && !(self::$instance instanceof datum)) {
				self::$instance = new datum;
			}
			return self::$instance;
		}
		
		public function __construct() {
					
			if (!$this->check_requirements()) {
				return;
			}
			$this->define_constants();
			$this->define_tables();
			$this->includes();
			$this->init_hooks();
			$this->create_options();
			//
			// Activation Hooks
			//
			register_deactivation_hook(__FILE__, array($this, 'deactivate'));
			register_uninstall_hook(__FILE__, 'datum::uninstall');
		}
		/**
		 * Define DM Constants.
		 */
		private function define_constants() {
			$upload_dir = wp_upload_dir( null, false );

			$this->define( 'DM_ABSPATH', dirname( DM_PLUGIN_FILE ) . '/' );
			$this->define( 'DM_PLUGIN_BASENAME', plugin_basename( DM_PLUGIN_FILE ) );
			$this->define( 'DM_VERSION', $this->version );
			$this->define( 'WOOCOMMERCE_VERSION', $this->version );
			$this->define( 'DM_DATE', date('Y-m-d H:i:s') );
			$this->define( 'DM_ROUNDING_PRECISION', 6 );
			$this->define( 'DM_DISCOUNT_ROUNDING_MODE', 2 );
			$this->define( 'DM_DELIMITER', '|' );
			$this->define( 'DM_LOG_DIR', $upload_dir['basedir'] . '/dm-logs/' );
			$this->define( 'DM_SESSION_CACHE_GROUP', 'dm_session_id' );
			$this->define( 'DM_TEMPLATE_DEBUG_MODE', false );
			$this->define( 'DM_NOTICE_MIN_PHP_VERSION', '7.2' );
			$this->define( 'DM_NOTICE_MIN_WP_VERSION', '5.2' );

			if(DM_PLUGIN_ENV == 'DEV'){
				$this->define( 'ZIP_URL', 'https://azurefunctionzipfilegenerate.azurewebsites.net/api/zip' );
				$this->define('Datum_API_URL', 'https://stgchildapi.datatodeals.com/api/v1/');
				$this->define( 'DOCUMENT_VAULT_URL', 'https://datumdocstorage.blob.core.windows.net/datumfilecontainer/PropertyDocuments-Dev' );
				$this->define( 'PARENTSITEURL', 'https://dev.datatodeals.com' );
				$this->define( 'DASHBOARDURL', 'https://dev-dashboard.datatodeals.com/' );
			}else if(DM_PLUGIN_ENV == 'LIVE'){
				$this->define( 'Datum_API_URL', 'https://childapi.datatodeals.com/api/v1/' );
	            $this->define( 'DOCUMENT_VAULT_URL', 'https://datumdoc.blob.core.windows.net/datumfilecontainer/PropertyDocuments' );
	            $this->define( 'ZIP_URL', 'https://azurefunctionzipfilegenerateproduction.azurewebsites.net/api/zip' );
	            $this->define( 'PARENTSITEURL', 'https://datatodeals.com' );
				$this->define( 'DASHBOARDURL', 'https://dashboard.datatodeals.com/' );
			}else if(DM_PLUGIN_ENV == 'QA'){
				$this->define( 'Datum_API_URL', 'https://qaapi.dealsfromdata.com/api/v1/' );
				$this->define( 'DOCUMENT_VAULT_URL', 'https://datumdocstorage.blob.core.windows.net/datumfilecontainer/PropertyDocuments-qa' );
				$this->define( 'ZIP_URL', 'https://azurefunctionzipfilegenerateqa.azurewebsites.net/api/zip' );
				$this->define( 'PARENTSITEURL', 'http://20.84.66.138:60' );
				$this->define( 'DASHBOARDURL', 'https://qa-dashboard.datatodeals.com/' );
			}

			$this->define( 'DATUM_PLUGIN_URL', plugin_dir_url( __DIR__ ) );
			$this->define( 'DATUM_PLUGIN_IMAGES_URL', plugin_dir_url( __DIR__ ).'images/' );
			$this->define( 'DATUM_DOCUMENTVAULT_PATH', $upload_dir['basedir']."/PropertyDocumentVault/" );
			$this->define( 'DATUM_SENDGRID_FROM_EMAIL', 'noreply@dealsfromdata.com');
			$this->define( 'DATUM_SENDGRID_FROM_NAME', 'Datum Inc' );
			$this->define( 'PRJECT_NAME', 'Datum Inc' );
            $this->define( 'DATUM_ILOVEPDF_KEY', 'project_public_38e9169b628d1d5956850f06a73a3678_MdeUPae0eff300f7c3984fb280e389c48a3ec' );
            $this->define( 'DATUM_ILOVEPDF_SECRET_KEY', 'secret_key_d8ca5fbfa93a57e9afa976aae0e20077_Ajh9H6a6412f9e14da3eb78f7be1d369d7f8b' );
			$this->define( 'SITENAME', get_bloginfo());
		}

		/**
		 * Register custom tables within $wpdb object.
		 */
		private function define_tables() {
			global $wpdb;

			// List of tables without prefixes.
			$tables = array(
			);

			foreach ( $tables as $name => $table ) {
				$wpdb->$name    = $wpdb->prefix . $table;
				//$wpdb->tables[] = $table;
			}
		}

		public function create_options(){
			include_once dirname( __FILE__ ) . '/admin/class-dm-admin-settings.php';
			$settings = DM_Admin_Settings::get_settings_pages();


			foreach ( $settings as $section ) {
				if ( ! method_exists( $section, 'get_settings' ) ) {
					continue;
				}
			}
		}

		private function define( $name, $value ) {
			if ( ! defined( $name ) ) {
				define( $name, $value );
			}
		}

		public function includes() {
			/**
			 * Core classes.
			 */
			
			
			include_once DM_ABSPATH . 'includes/dm-template-hooks.php';
			
			include_once DM_ABSPATH . 'includes/dm-template-functions.php';
			
			include_once DM_ABSPATH . 'includes/class-dm-frontend-scripts.php';
			
			include_once DM_ABSPATH . 'includes/class-dm-page.php';

			
			include_once DM_ABSPATH . 'includes/hybridauth/src/autoload.php';
			
			include_once DM_ABSPATH . 'includes/hybridauth/callback.php';

			include_once DM_ABSPATH . 'includes/class-dm-ajax.php';

			//include_once DM_ABSPATH . 'includes/hybridauth/config.php';

			include_once DM_ABSPATH . 'includes/class-dm-social.php';
			
			include_once DM_ABSPATH . 'includes/class-dm-signup.php';
			
			include_once DM_ABSPATH . 'includes/class-dm-curl.php';
			
			include_once DM_ABSPATH . 'includes/class-dm-query.php';
			
			include_once DM_ABSPATH . 'includes/class-dm-shortcode.php';
			
			include_once DM_ABSPATH . 'includes/dm-core-functions.php';
			
			include_once DM_ABSPATH . 'includes/class-datum-email-send.php';

			include_once DM_ABSPATH . 'library/sendgrid-API/sendgrid-php.php';

			include_once DM_ABSPATH . 'includes/hybridauth/config.php';

			include_once DM_ABSPATH . 'includes/class-hybridauth.php';
			
			if ( $this->is_request( 'admin' ) ) {
				include_once DM_ABSPATH . 'includes/admin/class-dm-admin.php';
			}
			
			include_once DM_ABSPATH . 'includes/Modules/propery-functions.php';
			
			include_once DM_ABSPATH . 'includes/Modules/user-functions.php';
			$this->query = new DM_Query();
			
			include_once DM_ABSPATH . 'includes/Modules/insight-functions.php';
            $this->query = new DM_Query();
		}

		private function is_request( $type ) {
			switch ( $type ) {
				case 'admin':
					return is_admin();
				case 'ajax':
					return defined( 'DOING_AJAX' );
				case 'cron':
					return defined( 'DOING_CRON' );
				case 'frontend':
					return ( ! is_admin() || defined( 'DOING_AJAX' ) ) && ! defined( 'DOING_CRON' ) && ! $this->is_rest_api_request();
			}
		}
	
		public function init_hooks(){

			//add_action('admin_enqueue_scripts', array($this,'admin_scripts_data') );
			add_action('wp_enqueue_scripts', array($this, 'custom_scripts'));

			//add_shortcode('news_shortcode',array($this, 'news_shortcode'));

			
			//Ajax
			add_action('wp_ajax_user_login',array($this, 'user_login'));
			add_action('wp_ajax_nopriv_user_login',array($this, 'user_login'));

			add_action('init', array($this, 'add_my_rule'));
			
			add_action('wp', array($this, 'checkValidPage'));

			//add_filter('wp_nav_menu_items', 'add_attribute', 10, 2);

			//add_filter( 'wp_nav_menu_items', array($this,'add_login_logout_register_menu'), 199, 2 );
			
			add_action( 'wp_head', array($this,'addFooterHtml'), 199, 2 );
		
            add_action( 'wp_footer', array($this,'userVerification'),1999,2);
			add_action( 'wp_footer', array($this,'loaderTemplate'));

            add_action( 'wp_head', array($this,'addHtmlH'),1999,2);
		}

		public function loaderTemplate(){
			ob_start();
            include DM_ABSPATH . 'template/loading.php';
            echo ob_get_clean();
		}
		/**
		 * Called when the plug-in is uninstalled
		 */
		static function uninstall() {
		}
		
		private function check_requirements() {
			global $wp_version;
			if (!version_compare($wp_version, $this->wp_version, '>=')) {
				add_action('admin_notices', 'datum::display_req_notice');
				return false;
			}
			return true;
		}
		
		public function custom_scripts(){
			?>
			<script type="text/javascript">
	    		var ajax_url = "<?php echo admin_url('admin-ajax.php'); ?>";
	    	</script>
			<?php 
		}

		public function add_my_rule(){
            $post_name   = dm_get_page_slug('datum_property_listing_id');
            $agent_id    = dm_get_page_slug('datum_agent_id');
            $post_closed = dm_get_page_slug('datum_property_closed_id');
			$post_for_lease = dm_get_page_slug('datum_for_lease_listing_id');
			
            global $wp;
            $wp->add_query_var('args');

            add_rewrite_rule($post_name.'/([^/]*)','index.php?pagename='.$post_name.'&args=$matches[1]','top');

            add_rewrite_rule($post_for_lease.'/([^/]*)','index.php?pagename='.$post_for_lease.'&args=$matches[1]','top');
			
            add_rewrite_rule($agent_id.'/([^/]*)','index.php?pagename='.$agent_id.'&args=$matches[1]','top');
            add_rewrite_rule($post_closed.'/([^/]*)','index.php?pagename='.$post_closed.'&args=$matches[1]','top');

            add_rewrite_rule('office/([^/]*)','index.php?pagename=office&args=$matches[1]','top');

			add_rewrite_rule('industrial/([^/]*)','index.php?pagename=industrial&args=$matches[1]','top');
			
			add_rewrite_rule('retail/([^/]*)','index.php?pagename=retail&args=$matches[1]','top');
			
			add_rewrite_rule('multifamily/([^/]*)','index.php?pagename=multifamily&args=$matches[1]','top');

			add_rewrite_rule('healthcare/([^/]*)','index.php?pagename=healthcare&args=$matches[1]','top');

			add_rewrite_rule('hospitality/([^/]*)','index.php?pagename=hospitality&args=$matches[1]','top');

			add_rewrite_rule('land-development/([^/]*)','index.php?pagename=land-development&args=$matches[1]','top');	

			add_rewrite_rule('insight/([^/]*)','index.php?pagename=insight&args=$matches[1]','top');
			
			add_rewrite_rule('preview/([^/]*)','index.php?pagename=preview&args=$matches[1]','top');

            global $wp_rewrite;
            $wp_rewrite->flush_rules();
        }
        
		public function add_login_logout_register_menu( $items, $args ){
			if ( $args->theme_location == 'primary' ) {
				if(isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
					$items .= '
						<li class="datum_user_profile"> 
	                      	<div class="half">
	                        	<label for="profile2" class="profile-dropdown">
	                          		<input type="checkbox" id="profile2">
	                          		<span>John Doe</span>
	                          		<img src="https://cdn0.iconfinder.com/data/icons/avatars-3/512/avatar_hipster_guy-512.png">
	                          		<label for="profile2"><i class="mdi mdi-menu"></i></label>
	                          		<ul>
			                            <li><a href="#"><i class="mdi mdi-email-outline"></i>Messages</a></li>
			                            <li><a href="#"><i class="mdi mdi-account"></i>Account</a></li>
			                            <li><a href="#"><i class="mdi mdi-settings"></i>Settings</a></li>
			                            <li><a href="#"><i class="mdi mdi-logout"></i>Logout</a></li>
	                         	 	</ul>
	                        	</label>
	                      	</div>
	                    </li>';
				}else{
					$items .= '<li><a data-property_id="" data-popup="login_html" class="datum_modal_toggle datum_model_open"> Login</a></li>';
				}
				return $items;
			}else{
				return $items;
			}
		}

		public function addFooterHtml(){
			echo '<div class="datum_modal" id="comman_model">
                    <div class="datum_modal_overlay" id="datum_popup_html"></div>
                  </div>
                  <div class="datum_modal fgd" id="change_password_model">
                    <div class="datum_modal_overlay" id="change_popup_html"></div>
                  </div>
                  <a style="display: none;" data-popup="register_new_html" class="modal-toggle-signup datum_btn_grey btn-lg datum_model_open register_new_html">Create New Account</a>
                  <a style="display: none;" data-popup="login_new_html" class="modal-toggle-signup datum_btn_grey btn-lg datum_model_open login_new_html">login</a>
                  ';

            ob_start();
            include DM_ABSPATH . 'template/auth/ProfileImage/profileimagepopup.php';
            echo ob_get_clean();

            ob_start();
            include DM_ABSPATH . 'template/auth/document_download_error.php';
            echo ob_get_clean();

            ob_start();
            include DM_ABSPATH . 'template/auth/document_access_remove.php';
            echo ob_get_clean();

			ob_start();
            include DM_ABSPATH . 'template/auth/success_popup.php';
            echo ob_get_clean();

			ob_start();
            include DM_ABSPATH . 'template/auth/change_membership_popup.php';
            echo ob_get_clean();

			ob_start();
            include DM_ABSPATH . 'template/auth/advanced_subscription.php';
            echo ob_get_clean();
		}
		
        public function userVerification(){
            if( isset( $_GET['datumpara'] ) && $_GET['datumpara'] !="") {
                $v_data = json_decode(base64_decode($_GET['datumpara']));
                if($v_data->dmaction != ''){
                    switch ($v_data->dmaction) {
                        case 'login':
                            ?>
                            <script type="text/javascript">
                                setTimeout(function(){
                                    jQuery(document).ready(function(){
                                        $('.datum_header_login').trigger( "click" );
                                    });
                                }, 200);
                            </script>
                            <?php
                            break;
                        case 'dashboard_verification':
                            if(isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
                                ?>
                                <script type="text/javascript">
                                    setTimeout(function(){
                                        jQuery(document).ready(function(){
                                            jQuery('#dashboard_verification_logout').trigger( "click" );
                                        });
                                    }, 200);
                                </script>
                                <?php
                            } else {
                                $verificationId = $v_data->verification_code;
                                $data = DM_Curl::HTTPPost(array('token'=>$verificationId, 'user_ip' => $_SERVER['REMOTE_ADDR']), 'check-email-token');

                                $data = json_decode($data);
                                if (strpos($verificationId, '/') !== false) {
                                    $verificationId = explode('/', $verificationId)[0];
                                }
                                set_transient( 'email', $v_data->username, 86400 );
                                set_transient( 'verificationId', $verificationId, 86400 );
                                set_transient( 'dashboardparameters', $_GET['datumpara'], 86400 );
                                $siteurl = home_url();

                                if($data->status == 'success') {
                                    ?>
                                    <script type="text/javascript">
                                        setTimeout(function(){
                                            jQuery(document).ready(function(){
                                                console.log(45);
                                                jQuery('#dashboard_verification_login').trigger( "click" );
                                            });
                                        }, 200);
                                    </script>
                                    <?php
                                } else {
                                    if(isset( $data->isVerifiedUser ) && $data->isVerifiedUser == 'yes') {
                                        ?>
                                        <script type="text/javascript">
                                            setTimeout(function(){
                                                jQuery(document).ready(function(){
                                                    window.history.replaceState({}, document.title, "?datumpara" + "");
                                                    $('.datum_header_login').trigger( "click" );
                                                });
                                            }, 200);
                                        </script>
                                        <?php
                                    } else {
                                        ?>
                                        <script type="text/javascript">
                                            window.location.href = '<?php echo $siteurl ?>';
                                        </script>
                                        <?php
                                    }
                                }
                            }

                            break;
                        case 'wordpress_verification':
                            $verificationId = $v_data->verification_code;
                            if (strpos($verificationId, '/') !== false) {
                                $verificationId = explode('/', $verificationId)[0];
                            }
                            $data = DM_Curl::HTTPPost(array('token'=>$verificationId, 'user_ip' => $_SERVER['REMOTE_ADDR']), 'find-verification');
                            $data = json_decode($data);

                            $siteurl = home_url();
                            if($data->status == 'success') {
                                set_transient( 'useremail', $data->email, 86400 );
                                ?>
                                <script type="text/javascript">
                                    setTimeout(function(){
                                        jQuery(document).ready(function(){
                                            window.history.replaceState({}, document.title, "?datumpara" + "");
                                            $('.datum_header_login').trigger( "click" );
                                        });
                                    }, 200);
                                </script>
                                <?php
                            } else {
                                ?>
                                <script type="text/javascript">
                                    window.location.href = '<?php echo $siteurl ?>';
                                </script>
                                <?php
                            }
                            break;
                        case 'wordpress_reset_password':
                            if(isset($v_data->reset_token_code) && $v_data->reset_token_code != "") {
                                $id = "find/".$v_data->reset_token_code;
                                $data = DM_Curl::HTTPGet($id);
                                $data = json_decode($data);
                                if($data->status == 'success') {
                                    ?>
                                    <a data-property_id="" data-token="<?php echo $v_data->reset_token_code; ?>" id="reset_password" data-popup="reset_password" data-main="1" class="datum_modal_toggle datum_model_open" style="display:none;">Reset Password</a>
                                    <script type="text/javascript">
                                        setTimeout(function(){
                                            jQuery(document).ready(function(){
                                                $('#reset_password').trigger( "click" );
                                                //popupHtml('reset_password');
                                                jQuery(document).on('click','#reset_password',function(e){
                                                    //setTimeout(function(){
                                                    popupHtml('reset_password');
                                                    //}, 2000);
                                                });
                                            });
                                        }, 2000);
                                    </script>
                                    <?php
                                }
                            }

                            break;
                        default:
                            // code...
                            break;
                    }
                }
            }

            if( isset($_GET['dmaction'] ) && base64_decode($_GET['dmaction']) !="") {
                ?>
                <script type="text/javascript">
                    setTimeout(function(){
                        jQuery(document).ready(function(){
                            $('.datum_header_login').trigger( "click" );
                        });
                    }, 3000);
                </script>
                <?php
            }

            if( isset($_GET['social_login']) && $_GET['social_login'] != '' ) { ?>
            	
            <?php }
            if( isset($_GET['code1']) && $_GET['code1'] != '' ) {
            	global $social;
            	global $social_email;

            	//include_once DM_ABSPATH . 'includes/hybridauth/config.php';

            	if( isset($social) && $social == 'login' ) {
            		?>
            		
            	<?php }else{?>
	            	<script type="text/javascript">
	            		setTimeout(function(){
	                    	jQuery(document).ready(function(){
	                        	$('.register_new_html').trigger( "click" );
	                    	});
	                    }, 1000);
	                </script>
            	<?php }
            	?>
            	<?php
            }

			if( isset($_GET['success']) && $_GET['success'] != '' ) {
				?>
                <script type="text/javascript">
                    setTimeout(function(){
                        jQuery(document).ready(function(){
                            $('#success_download_error').toggleClass('is-visible');
                        });
                    }, 3000);
                </script>
                <?php
			}
        }
        
	}
}
?>
