<?php
/**
 * datum setup
 *
 * @package datum
 * @since   3.2.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Main datum Class.
 *
 * @class datum
 */
if(!class_exists('WP_List_Table')){
   require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}
if (!class_exists('datumPage')) {
		
	class datumPage {
		
		public function __construct() {
			$this->includes();
			$this->init_hooks();
			add_action( 'wp_head', array($this,'addHeaderHtml'), 199, 2 );
			add_action( 'wp_head', array($this,'addHeaderAgent'), 2, 2 );
		}

		public function includes() {
			foreach ( $this->pageData() as $key => $value ) {
				
				include_once DM_ABSPATH . 'includes/page/class-'.$key.'.php';
			}
		}

		public function init_hooks(){

			add_filter( 'template_include', array($this, 'include_template_function'));
		}


		public function addHeaderHtml(){
			global $single_property,$post, $single_insight;
			if(isset($single_property) && !empty($single_property)){

				$list = getimagesize(getDMpropertyFeaturedImageSM());
			?>
				<?php
					if(empty(getDMPropertyMetaTitle()))
					{
						$meta_title = getDMPropertyName()." - ".PRJECT_NAME;
					}
					else {
						$meta_title = getDMPropertyMetaTitle();
					}
				?>
				<title><?php echo $meta_title; ?></title>
				<meta name="description" content="<?php echo getDMPropertyMetaDescription(); ?>" />
				<meta name="robots" content="index, follow, max-snippet:-1, max-image-preview:large, max-video-preview:-1" />
				<meta property="og:locale" content="en_US" />
				<meta property="og:type" content="article" />
				<meta name="title" property="og:title" content="<?php echo $meta_title ?>" />
				<meta property="og:description" content="<?php echo getDMPropertyMetaDescription(); ?>" />
				<meta property="og:url" content="<?php echo getDMProperyURL(); ?>" />
				<meta property="og:site_name" content="<?php echo PRJECT_NAME; ?>" />
				<meta property="article:publisher" content="https://www.facebook.com/datatodeals/" />
				<meta property="article:published_time" content="2021-06-03T19:21:08+00:00" />
				<meta property="article:modified_time" content="2021-06-06T01:01:29+00:00" />
				<meta name="image" property="og:image" content="<?php echo getDMpropertyFeaturedImageSM(); ?>" />
				<meta property="og:image:width" content="<?php echo $list[0] ?>" />
				<meta property="og:image:height" content="<?php echo $list[1] ?>" />
				<meta name="twitter:card" content="summary_large_image" />
				<meta name="twitter:creator" content="@datatodeals" />
				<meta name="twitter:site" content="@datatodeals" />
				
			<?php
			} else {
				if(isset($single_insight) && !empty($single_insight)){
					if(empty(getDMInsightPostTitle()))
					{
						$meta_title = getDMInsightPostTitle()." - ".PRJECT_NAME;
					}
					else {
						$meta_title = getDMInsightPostTitle()." - ".PRJECT_NAME;
					}
					?>
					<title><?php echo $meta_title; ?></title>
					<meta name="description" content="<?php echo $single_insight->MetaDescription; ?>" />
					<meta name="robots" content="index, follow, max-snippet:-1, max-image-preview:large, max-video-preview:-1" />
					<?php
				}
			}
		}
		

		public function addHeaderAgent(){
			global $single_property,$post;
			if($post->ID == get_option('datum_agent_id')){
				global $agentDetails;
				?>
				<title><?php echo $agentDetails->FirstName; ?> <?php echo $agentDetails->LastName; ?> | <?php echo PRJECT_NAME; ?></title>
				
				<meta name="robots" content="index, follow, max-snippet:-1, max-image-preview:large, max-video-preview:-1" />
				<meta property="og:locale" content="en_US" />
				<meta property="og:type" content="article" />
				<meta name="description" content="<?php echo $agentDetails->FirstName; ?> <?php echo $agentDetails->LastName; ?>" />
				<?php
			}
		}


		public function include_template_function( $template_path ) {
			global $post,$wp,$property_type_filter,$siteData;
			
			global $datum_user,$site_name;
			$page_name = '';
			foreach ($this->pageData() as $key => $value) {
				$id  = get_option($value);

				if($id == $post->ID){
					
					if($value == 'datum_my_listing_page_id'){
						$page_name = $key;
						if(isset($_COOKIE['access_token']) && $_COOKIE['access_token'] != '') {
						}else{
							wp_redirect( home_url() );
						}
					}else{
						
						$page_name = $key;
					}
					 break;
				}else{
					
					$page_name = '';
				}
			}

			$data = json_decode(DM_Curl::HTTPGet('check-plugin-key'));
			

			if($data->status == 'success'){
				if(!get_option('ConfigurationId')){
					add_option('ConfigurationId', $data->data->ConfigurationId);
				}else{
					update_option('ConfigurationId', $data->data->ConfigurationId);
				}
				$siteData = $data->data;
				if(!empty($data->user_data)){
					$datum_user = $data->user_data;
				}else{
					unset($_COOKIE['access_token']);
					setcookie('access_token', null, -1, '/');
					//unset($_SESSION['HYBRIDAUTH::STORAGE']);
				}
				//$data = DM_Curl::HTTPPost(array('insight_id' => 30, 'is_Insightview' => 'true') , 'insight-page');
				
				if(isset($page_name) && $page_name != ''){
					if($page_name == 'listing' || $page_name == 'closed' || $page_name == 'for_lease'){
						add_filter( 'body_class','addListingPageClass' );
					}

					return $page_name::output($template_path);
				}else{
					
					$args 		= get_query_var('args');
					$pagename 	= get_query_var('pagename');
					
					$ss = 'listing';
					$property_type_filter = $pagename;
					
					if(in_array($pagename,$this->checkpage()) && $args == 'for-sale' ){
						add_filter( 'body_class','addListingPageClass' );
						return $ss::propertyTypeOutput($template_path);
					}elseif(in_array($pagename,$this->checkpage()) && $args == 'closed' ){
						add_filter( 'body_class','addListingPageClass' );
						return $ss::propertyTypeClosedOutput($template_path);
					} elseif(in_array($pagename,$this->checkpage()) && $args == 'for-lease' ){
						add_filter( 'body_class','addListingPageClass' );
						return $ss::propertyLeaseTypeOutput($template_path);
					}elseif(in_array($pagename,$this->checkpage())){
						return $template_path = get_template_directory() . '/404.php';
					}else{

						return $template_path;
					}
				}
			}else{
				return $template_path;
			}

		}
		public function check_condition(){

		}

		public function checkpage(){
			return array(
				'office',
				'industrial',
				'retail',
				'multifamily',
				'healthcare',
				'hospitality',
				'land-development'
			);
		}

		public function pageData(){
			return array(
				'listing' 					=> 'datum_property_listing_id',
				'closed' 					=> 'datum_property_closed_id',
				'agent'        			    => 'datum_agent_id',
				'insight' 					=> 'datum_insights_page_id',
				'preview' 					=> 'datum_preview_page_id',
				'my_listing' 				=> 'datum_my_listing_page_id',
				'for_lease' 				=> 'datum_for_lease_listing_id',
				'success' 				=> 'datum_success_page_id',
				'failed' 				=> 'datum_failed_page_id'
				//'proerty_type'			=> 'datum_type_listing_page_id'
			);
		}
	}
}
return new datumPage();

function addListingPageClass($classes){
	
	$classes[] = 'listing_page_class';
    return $classes;
}